@@ -23,9 +23,6 @@
 #include "settings.h"
 #include "qzsettings.h"
 #include "tabwidget.h"
-#include "clickablelabel.h"
-#include "buttonwithmenu.h"
-#include "searchenginesmanager.h"
 #include "searchenginesdialog.h"
 #include "networkmanager.h"
 #include "iconprovider.h"
@@ -237,7 +234,7 @@ void WebSearchBar::searchInNewTab()
 
 void WebSearchBar::addEngineFromAction()
 {
-    if (QAction* action = qobject_cast<QAction*>(sender())) {
+    if (auto* action = qobject_cast<QAction*>(sender())) {
         m_searchManager->addEngine(action->data().toUrl());
     }
 }
